
import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';

import { MessageService } from './message.service';
import { serviceBaseUrl } from './config';


import { Account, Fee, OverheadAdvance } from './data-objects';
import { Saldo, Tenant_with_Saldo } from './ext-data-objects';


@Injectable({ providedIn: 'root' })
export class ExtApiService {
  constructor(private messageService: MessageService, private http: HttpClient) { }
  
  async getOverheadAdvancesByFlat(id: number): Promise<OverheadAdvance[]> {
    this.messageService.add(`ExtApiService: get overheadadvances by flat ${id}`);
    return this.http.get<OverheadAdvance[]>(`${serviceBaseUrl}/v1/overhead_advances/flat/${id}`).toPromise()
  }
  
  async getAccountByDescription(description: string): Promise<Account> {
    this.messageService.add(`ExtApiService: get account by description ${description}`);
    return this.http.get<Account>(`${serviceBaseUrl}/v1/accounts/bydescription/${description}`).toPromise()
  }

  async getFeeByTenancies(id: number): Promise<Fee[]> {
    this.messageService.add(`ExtApiService: get fees by flat ${id}`);
    return this.http.get<Fee[]>(`${serviceBaseUrl}/v1/fees/tenancy/${id}`).toPromise()
  }

  async getAccountSaldo(id: number): Promise<Saldo> {
    this.messageService.add(`ExtApiService: get saldo for account ${id}`);
    return this.http.get<Saldo>(`${serviceBaseUrl}/v1/account/saldo/${id}`).toPromise()
  }

  async getTenantsWithSaldo(): Promise<Tenant_with_Saldo[]> {
    this.messageService.add("ExtApiService: get tenants with saldo");
    return this.http.get<Tenant_with_Saldo[]>(`${serviceBaseUrl}/v1/tenants/saldo`).toPromise()
  }
}
